<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>MircastShowWidget</name>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="74"/>
        <source>Exit Miracast</source>
        <translation>退出投屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="93"/>
        <source>Projecting... 
Please do not exit the Movie app during the process.</source>
        <translation>正在投屏，投屏过程中请勿退出影院。</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastshowwidget.cpp" line="126"/>
        <source>Display device</source>
        <translation>投屏设备</translation>
    </message>
</context>
<context>
    <name>MircastWidget</name>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="79"/>
        <source>Project to</source>
        <translation>投屏到</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="447"/>
        <source>Searching for devices...</source>
        <translation>正在查找设备...</translation>
    </message>
    <message>
        <location filename="../src/widgets/mircastwidget.cpp" line="456"/>
        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
        <translation>暂无可投屏设备，请确保所投屏设备和您的电脑连接同一无线网络</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="765"/>
        <location filename="../src/common/dmr_settings.cpp" line="410"/>
        <location filename="../src/common/volumemonitoring.cpp" line="76"/>
        <location filename="../src/main.cpp" line="375"/>
        <location filename="../src/main.cpp" line="482"/>
        <location filename="../src/widgets/platform/platform_volumeslider.cpp" line="128"/>
        <location filename="../src/widgets/volumeslider.cpp" line="121"/>
        <source>Movie</source>
        <translation>影院</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="376"/>
        <source>Movie is a full-featured video player, supporting playing local and streaming media in multiple video formats.</source>
        <translation>影院是一款支持多种视频格式本地播放和流媒体播放的视频播放器。</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="61"/>
        <location filename="../src/common/shortcut_manager.cpp" line="210"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="59"/>
        <location filename="../src/common/shortcut_manager.cpp" line="213"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="60"/>
        <location filename="../src/common/shortcut_manager.cpp" line="218"/>
        <source>Display shortcuts</source>
        <translation>显示快捷键</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="12"/>
        <source>Auto add similar files to play</source>
        <translation>自动查找相似文件连续播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="13"/>
        <source>Clear playlist when exit</source>
        <translation>退出影院时清空播放列表</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="14"/>
        <source>Show thumbnails in progress bar</source>
        <translation>进度条显示为胶片样式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="15"/>
        <source>Show video preview on mouseover</source>
        <translation>鼠标悬停进度条时显示预览</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="16"/>
        <source>Open a new player for each file played</source>
        <translation>允许同时运行多个影院</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="17"/>
        <source>Pause when minimized</source>
        <translation>最小化时暂停</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="18"/>
        <source>Remember playback position</source>
        <translation>自动从上次停止位置播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="19"/>
        <source>Default play mode</source>
        <translation>默认播放模式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="20"/>
        <source>Path</source>
        <translation>保存路径</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="21"/>
        <source>Basic</source>
        <translation>基础设置</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="22"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="23"/>
        <location filename="../src/common/settings_translation.cpp" line="28"/>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="24"/>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="25"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="26"/>
        <source>Frame/Sound</source>
        <translation>画面/声音</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="27"/>
        <source>Playback</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="29"/>
        <location filename="../src/common/settings_translation.cpp" line="30"/>
        <source>Subtitle</source>
        <translation>字幕</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="31"/>
        <source>Font Style</source>
        <translation>字体样式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="32"/>
        <source>Restore Defaults</source>
        <translation>恢复默认</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="33"/>
        <source>Open file</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="34"/>
        <source>Open next</source>
        <translation>打开下一个</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="35"/>
        <source>Open previous</source>
        <translation>打开上一个</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="36"/>
        <source>Mini mode</source>
        <translation>迷你模式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="37"/>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="38"/>
        <source>Next frame</source>
        <translation>下一帧</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="39"/>
        <source>Previous frame</source>
        <translation>上一帧</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="40"/>
        <source>Volume down</source>
        <translation>减小音量</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="41"/>
        <source>Volume up</source>
        <translation>增大音量</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="42"/>
        <source>Speed up</source>
        <translation>加速播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="43"/>
        <source>Speed down</source>
        <translation>减速播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="44"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="45"/>
        <source>Pause/Play</source>
        <translation>暂停/播放</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="46"/>
        <source>Playlist</source>
        <translation>播放列表</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="47"/>
        <source>Reset speed</source>
        <translation>还原播放速度</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="48"/>
        <source>Delete from playlist</source>
        <translation>从播放列表删除</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="49"/>
        <source>Film info</source>
        <translation>影片信息</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="50"/>
        <source>Rewind</source>
        <translation>快退</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="51"/>
        <source>Forward</source>
        <translation>快进</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="52"/>
        <source>Burst shooting</source>
        <translation>连拍截图</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="53"/>
        <source>Film screenshot</source>
        <translation>影片截图</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="54"/>
        <source>0.5s backward</source>
        <translation>字幕延迟0.5秒</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="55"/>
        <source>0.5s forward</source>
        <translation>字幕提前0.5秒</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="56"/>
        <source>Font</source>
        <translation>字体</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="57"/>
        <source>Size</source>
        <translation>字号</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="58"/>
        <source>Exit fullscreen/mini mode</source>
        <translation>退出全屏/迷你模式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="62"/>
        <source>Decoding</source>
        <translation>解码方式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="63"/>
        <source>Auto select (Recommended)</source>
        <translation>自动选择（推荐）</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="64"/>
        <source>Hardware decoding</source>
        <translation>硬件解码</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="65"/>
        <source>Software decoding</source>
        <translation>软件解码</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="66"/>
        <source>Customize</source>
        <translation>专业模式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="67"/>
        <source>Decode mode</source>
        <translation>解码方式</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="68"/>
        <source>Video out</source>
        <translation>输出驱动</translation>
    </message>
    <message>
        <location filename="../src/common/settings_translation.cpp" line="69"/>
        <source>Rendering engine</source>
        <translation>渲染引擎</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="364"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="366"/>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>此文件夹没有操作权限</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="366"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="368"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="382"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="388"/>
        <source>Invalid folder</source>
        <translation>此文件夹无效</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="402"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="414"/>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3277"/>
        <location filename="../src/common/mainwindow.cpp" line="3311"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3334"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3370"/>
        <source>The custom decoding method needs to be restarted before it can take effect,
and whether to restart it?</source>
        <translation>自定义解码方式需要重启后才能生效，
是否重启？</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3809"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3803"/>
        <source>Network disconnected</source>
        <translation>网络已断开</translation>
    </message>
</context>
<context>
    <name>UrlDialog</name>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="20"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="21"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../src/widgets/url_dialog.cpp" line="27"/>
        <source>Please enter the URL:</source>
        <translation>请输入您要播放文件的网络地址：</translation>
    </message>
</context>
<context>
    <name>dmr::ActionFactory</name>
    <message>
        <location filename="../src/common/actions.cpp" line="58"/>
        <location filename="../src/common/actions.cpp" line="140"/>
        <location filename="../src/common/actions.cpp" line="329"/>
        <source>Open file</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="61"/>
        <location filename="../src/common/actions.cpp" line="141"/>
        <location filename="../src/common/actions.cpp" line="330"/>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="62"/>
        <location filename="../src/common/actions.cpp" line="323"/>
        <location filename="../src/common/actions.cpp" line="381"/>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="73"/>
        <location filename="../src/common/actions.cpp" line="151"/>
        <location filename="../src/common/actions.cpp" line="340"/>
        <source>Play Mode</source>
        <translation>播放模式</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="75"/>
        <location filename="../src/common/actions.cpp" line="153"/>
        <location filename="../src/common/actions.cpp" line="342"/>
        <source>Order Play</source>
        <translation>顺序播放</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="76"/>
        <location filename="../src/common/actions.cpp" line="154"/>
        <location filename="../src/common/actions.cpp" line="343"/>
        <source>Shuffle Play</source>
        <translation>随机播放</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="77"/>
        <location filename="../src/common/actions.cpp" line="155"/>
        <location filename="../src/common/actions.cpp" line="344"/>
        <source>Single Play</source>
        <translation>单个播放</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="78"/>
        <location filename="../src/common/actions.cpp" line="156"/>
        <location filename="../src/common/actions.cpp" line="345"/>
        <source>Single Loop</source>
        <translation>单个循环</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="79"/>
        <location filename="../src/common/actions.cpp" line="157"/>
        <location filename="../src/common/actions.cpp" line="346"/>
        <source>List Loop</source>
        <translation>列表循环</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="84"/>
        <location filename="../src/common/actions.cpp" line="177"/>
        <source>Frame</source>
        <translation>画面</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="86"/>
        <location filename="../src/common/actions.cpp" line="179"/>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="93"/>
        <location filename="../src/common/actions.cpp" line="186"/>
        <source>Clockwise</source>
        <translation>顺时针旋转</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="94"/>
        <location filename="../src/common/actions.cpp" line="187"/>
        <source>Counterclockwise</source>
        <translation>逆时针旋转</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="96"/>
        <location filename="../src/common/actions.cpp" line="189"/>
        <source>Next Frame</source>
        <translation>下一帧</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="97"/>
        <location filename="../src/common/actions.cpp" line="190"/>
        <source>Previous Frame</source>
        <translation>上一帧</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="106"/>
        <location filename="../src/common/actions.cpp" line="162"/>
        <location filename="../src/common/actions.cpp" line="351"/>
        <source>Playback Speed</source>
        <translation>倍速播放</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="108"/>
        <location filename="../src/common/actions.cpp" line="164"/>
        <location filename="../src/common/actions.cpp" line="353"/>
        <source>0.5x</source>
        <translation>0.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="109"/>
        <location filename="../src/common/actions.cpp" line="165"/>
        <location filename="../src/common/actions.cpp" line="354"/>
        <source>1.0x</source>
        <translation>1.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="110"/>
        <location filename="../src/common/actions.cpp" line="166"/>
        <location filename="../src/common/actions.cpp" line="355"/>
        <source>1.2x</source>
        <translation>1.2x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="111"/>
        <location filename="../src/common/actions.cpp" line="167"/>
        <location filename="../src/common/actions.cpp" line="356"/>
        <source>1.5x</source>
        <translation>1.5x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="112"/>
        <location filename="../src/common/actions.cpp" line="168"/>
        <location filename="../src/common/actions.cpp" line="357"/>
        <source>2.0x</source>
        <translation>2.0x</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="142"/>
        <location filename="../src/common/actions.cpp" line="331"/>
        <source>Open URL</source>
        <translation>打开URL</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="143"/>
        <location filename="../src/common/actions.cpp" line="332"/>
        <source>Open CD/DVD</source>
        <translation>播放光盘</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="145"/>
        <location filename="../src/common/actions.cpp" line="334"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="146"/>
        <location filename="../src/common/actions.cpp" line="335"/>
        <source>Mini Mode</source>
        <translation>迷你模式</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="147"/>
        <location filename="../src/common/actions.cpp" line="336"/>
        <source>Always on Top</source>
        <translation>置顶窗口</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="200"/>
        <source>Sound</source>
        <translation>声音</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="204"/>
        <source>Channel</source>
        <translation>声道</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="207"/>
        <source>Stereo</source>
        <translation>立体声</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="208"/>
        <source>Left channel</source>
        <translation>左声道</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="209"/>
        <source>Right channel</source>
        <translation>右声道</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="214"/>
        <location filename="../src/common/actions.cpp" line="451"/>
        <source>Track</source>
        <translation>音轨</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="227"/>
        <source>Subtitle</source>
        <translation>字幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="229"/>
        <source>Load</source>
        <translation>载入字幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="230"/>
        <source>Online Search</source>
        <translation>查找在线字幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="234"/>
        <source>Select</source>
        <translation>选择字幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="238"/>
        <source>Hide</source>
        <translation>隐藏字幕</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="241"/>
        <source>Encodings</source>
        <translation>编码</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="308"/>
        <location filename="../src/common/actions.cpp" line="367"/>
        <source>Screenshot</source>
        <translation>截图</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="311"/>
        <location filename="../src/common/actions.cpp" line="370"/>
        <source>Film Screenshot</source>
        <translation>影片截图</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="312"/>
        <source>Burst Shooting</source>
        <translation>连拍截图</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="313"/>
        <location filename="../src/common/actions.cpp" line="371"/>
        <source>Open screenshot folder</source>
        <translation>前往截图文件夹</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="321"/>
        <location filename="../src/common/actions.cpp" line="379"/>
        <source>Playlist</source>
        <translation>播放列表</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="322"/>
        <location filename="../src/common/actions.cpp" line="380"/>
        <source>Film Info</source>
        <translation>影片信息</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="394"/>
        <source>Delete from playlist</source>
        <translation>从播放列表删除</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="395"/>
        <source>Empty playlist</source>
        <translation>清空播放列表</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="396"/>
        <source>Display in file manager</source>
        <translation>在文件管理器中显示</translation>
    </message>
    <message>
        <location filename="../src/common/actions.cpp" line="397"/>
        <source>Film info</source>
        <translation>影片信息</translation>
    </message>
</context>
<context>
    <name>dmr::BurstScreenshotsDialog</name>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="49"/>
        <source>Duration: %1</source>
        <translation>时长：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="55"/>
        <source>Resolution: %1</source>
        <translation>分辨率：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="61"/>
        <source>Size: %1</source>
        <translation>影片大小：%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/burst_screenshots_dialog.cpp" line="88"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
</context>
<context>
    <name>dmr::MainWindow</name>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1145"/>
        <location filename="../src/common/mainwindow.cpp" line="2920"/>
        <location filename="../src/common/mainwindow.cpp" line="5557"/>
        <source>Load successfully</source>
        <translation>载入字幕成功</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="1145"/>
        <location filename="../src/common/mainwindow.cpp" line="2920"/>
        <location filename="../src/common/mainwindow.cpp" line="2924"/>
        <location filename="../src/common/mainwindow.cpp" line="5557"/>
        <source>Load failed</source>
        <translation>载入字幕失败</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2085"/>
        <location filename="../src/common/mainwindow.cpp" line="3526"/>
        <source>Cannot play the disc</source>
        <translation>无法播放光盘内容</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2105"/>
        <location filename="../src/common/mainwindow.cpp" line="4235"/>
        <source>Parse failed</source>
        <translation>解析失败</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2113"/>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2600"/>
        <location filename="../src/common/mainwindow.cpp" line="2610"/>
        <location filename="../src/common/mainwindow.cpp" line="2620"/>
        <location filename="../src/common/mainwindow.cpp" line="2630"/>
        <location filename="../src/common/mainwindow.cpp" line="2640"/>
        <location filename="../src/common/mainwindow.cpp" line="2889"/>
        <location filename="../src/common/mainwindow.cpp" line="5768"/>
        <source>Speed: %1x</source>
        <translation>播放速度：%1倍</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2648"/>
        <source>Stereo</source>
        <translation>立体声</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2654"/>
        <source>Left channel</source>
        <translation>左声道</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2660"/>
        <source>Right channel</source>
        <translation>右声道</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2788"/>
        <source>Track: %1</source>
        <translation>音轨：%1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2840"/>
        <location filename="../src/common/mainwindow.cpp" line="2860"/>
        <source>Unable to adjust the subtitle</source>
        <translation>当前字幕不可调节</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2845"/>
        <location filename="../src/common/mainwindow.cpp" line="2865"/>
        <source>Subtitle %1: %2s</source>
        <translation>字幕%1：%2秒</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2846"/>
        <location filename="../src/common/mainwindow.cpp" line="2866"/>
        <source>delayed</source>
        <translation>延迟</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2846"/>
        <location filename="../src/common/mainwindow.cpp" line="2866"/>
        <source>advanced</source>
        <translation>提前</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3035"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3044"/>
        <source>Film screenshot</source>
        <translation>影片截图</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3045"/>
        <source>Saved to</source>
        <translation>保存到</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3066"/>
        <location filename="../src/common/mainwindow.cpp" line="3222"/>
        <source>The screenshot is saved</source>
        <translation>截图已保存</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3070"/>
        <location filename="../src/common/mainwindow.cpp" line="3227"/>
        <source>Failed to save the screenshot</source>
        <translation>截图保存失败</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3173"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>正在截图，请稍候...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3277"/>
        <location filename="../src/common/mainwindow.cpp" line="3311"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3278"/>
        <location filename="../src/common/mainwindow.cpp" line="3312"/>
        <source>Restart</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3420"/>
        <source>Professional mode is only for professionals to use</source>
        <translation>专业模式仅供专业人员使用</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3421"/>
        <source>During the adaptation process, there may be issues such as screen distortion, freezing, stuttering, torn images,
unsynchronized audio and video, and player crashes. Please use with caution.</source>
        <translation>适配过程中可能出现花屏、卡死、卡顿、画面撕裂、音画不同步、
播放器闪退等问题，请谨慎使用。</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3532"/>
        <source>Reading DVD files...</source>
        <translation>正在读取光盘文件...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="5886"/>
        <source>Invalid file: %1</source>
        <translation>无效文件：%1</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="5922"/>
        <source>Miracast disconnected</source>
        <translation>投屏已断开</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3834"/>
        <source>No matching online subtitles</source>
        <translation>未找到匹配的在线字幕</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2152"/>
        <location filename="../src/common/mainwindow.cpp" line="2195"/>
        <source>All (*)</source>
        <translation>所有 (*)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3852"/>
        <source>4K video may be stuck</source>
        <translation>播放4K视频可能会出现卡顿</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3423"/>
        <location filename="../src/common/mainwindow.cpp" line="3853"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3887"/>
        <location filename="../src/common/mainwindow.cpp" line="5072"/>
        <source>Order play</source>
        <translation>顺序播放</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3891"/>
        <location filename="../src/common/mainwindow.cpp" line="5076"/>
        <source>Shuffle play</source>
        <translation>随机播放</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3895"/>
        <location filename="../src/common/mainwindow.cpp" line="5080"/>
        <source>Single play</source>
        <translation>单个播放</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3899"/>
        <location filename="../src/common/mainwindow.cpp" line="5084"/>
        <source>Single loop</source>
        <translation>单个循环</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="3903"/>
        <location filename="../src/common/mainwindow.cpp" line="5088"/>
        <source>List loop</source>
        <translation>列表循环</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4076"/>
        <source>Buffering...</source>
        <translation>缓冲中...</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4116"/>
        <location filename="../src/common/mainwindow.cpp" line="4143"/>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4119"/>
        <location filename="../src/common/mainwindow.cpp" line="4145"/>
        <source>Volume: %1%</source>
        <translation>音量：%1%</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4162"/>
        <location filename="../src/common/mainwindow.cpp" line="4224"/>
        <source>Cannot open file or stream</source>
        <translation>无法打开文件或者流</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="5874"/>
        <source>The action is not supported in this video</source>
        <translation>当前视频不支持该功能</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="5914"/>
        <source>Connection failed</source>
        <translation>连接失败</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4245"/>
        <location filename="../src/common/mainwindow.cpp" line="4251"/>
        <source>Invalid file</source>
        <translation>无效文件</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="2899"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>字幕文件 (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4254"/>
        <source>Please insert a CD/DVD</source>
        <translation>请插入CD或DVD</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="4261"/>
        <source>No video file found</source>
        <translation>没有找到视频文件</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="5062"/>
        <source>Please load the video first</source>
        <translation>请先载入影片</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="5227"/>
        <location filename="../src/common/mainwindow.cpp" line="5237"/>
        <source>Please exit smart dock</source>
        <translation>Please exit smart dock</translation>
    </message>
    <message>
        <location filename="../src/common/mainwindow.cpp" line="5610"/>
        <source>The CD/DVD has been ejected</source>
        <translation>CD/DVD已弹出</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfo</name>
    <message>
        <location filename="../src/libdmr/playlist_model.h" line="113"/>
        <source>%1G</source>
        <translation>%1G</translation>
    </message>
    <message>
        <location filename="../src/libdmr/playlist_model.h" line="115"/>
        <source>%1M</source>
        <translation>%1M</translation>
    </message>
    <message>
        <location filename="../src/libdmr/playlist_model.h" line="117"/>
        <source>%1K</source>
        <translation>%1K</translation>
    </message>
    <message>
        <location filename="../src/libdmr/playlist_model.h" line="119"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>dmr::MovieInfoDialog</name>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="307"/>
        <source>Film info</source>
        <translation>影片信息</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="361"/>
        <source>Type</source>
        <translation>文件类型</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="362"/>
        <source>Size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="363"/>
        <source>Duration</source>
        <translation>时长</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="368"/>
        <source>Path</source>
        <translation>文件路径</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="374"/>
        <source>Codec info</source>
        <translation>编码信息</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="395"/>
        <source>Video CodecID</source>
        <translation>视频流信息</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="396"/>
        <source>Video CodeRate</source>
        <translation>视频码率</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="340"/>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="353"/>
        <source>%1 kbps</source>
        <translation>%1 kbps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="341"/>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="354"/>
        <source>%1 bps</source>
        <translation>%1 bps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="397"/>
        <source>FPS</source>
        <translation>视频帧率</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="343"/>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="398"/>
        <source>Proportion</source>
        <translation>显示比例</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="344"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="399"/>
        <source>Resolution</source>
        <translation>分辨率</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="405"/>
        <source>Audio info</source>
        <translation>音频流信息</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="426"/>
        <source>Audio CodecID</source>
        <translation>编码样式</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="427"/>
        <source>Audio CodeRate</source>
        <translation>编码码率</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="428"/>
        <source>Audio digit</source>
        <translation>音频位数</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="356"/>
        <source>%1 bits</source>
        <translation>%1 bits</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="429"/>
        <source>Channels</source>
        <translation>声道数</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="357"/>
        <source>%1 channels</source>
        <translation>%1 声道</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="430"/>
        <source>Sampling</source>
        <translation>采样数</translation>
    </message>
    <message>
        <location filename="../src/widgets/movieinfo_dialog.cpp" line="358"/>
        <source>%1hz</source>
        <translation>%1hz</translation>
    </message>
</context>
<context>
    <name>dmr::MpvProxy</name>
    <message>
        <location filename="../src/backends/mpv/mpv_proxy.cpp" line="2371"/>
        <source>Internal</source>
        <translation>内部</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_MainWindow</name>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1176"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2964"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5495"/>
        <source>Load successfully</source>
        <translation>载入字幕成功</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="1176"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2964"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2968"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5495"/>
        <source>Load failed</source>
        <translation>载入字幕失败</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2177"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3555"/>
        <source>Cannot play the disc</source>
        <translation>无法播放光盘内容</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2198"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4223"/>
        <source>Parse failed</source>
        <translation>解析失败</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2207"/>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2239"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2272"/>
        <source>All (*)</source>
        <translation>所有 (*)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2642"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2652"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2662"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2672"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2682"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2933"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5721"/>
        <source>Speed: %1x</source>
        <translation>播放速度：%1倍</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2690"/>
        <source>Stereo</source>
        <translation>立体声</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2696"/>
        <source>Left channel</source>
        <translation>左声道</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2702"/>
        <source>Right channel</source>
        <translation>右声道</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2832"/>
        <source>Track: %1</source>
        <translation>音轨：%1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2884"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2904"/>
        <source>Unable to adjust the subtitle</source>
        <translation>当前字幕不可调节</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2889"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2909"/>
        <source>Subtitle %1: %2s</source>
        <translation>字幕%1：%2秒</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2890"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2910"/>
        <source>delayed</source>
        <translation>延迟</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2890"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2910"/>
        <source>advanced</source>
        <translation>提前</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="2943"/>
        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
        <comment>All (*)</comment>
        <translation>字幕文件 (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3094"/>
        <source>View</source>
        <translation>查看</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3103"/>
        <source>Film screenshot</source>
        <translation>影片截图</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3104"/>
        <source>Saved to</source>
        <translation>保存到</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3125"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3279"/>
        <source>The screenshot is saved</source>
        <translation>截图已保存</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3129"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3284"/>
        <source>Failed to save the screenshot</source>
        <translation>截图保存失败</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3232"/>
        <source>Taking the screenshots, please wait...</source>
        <translation>正在截图，请稍候...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3334"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3370"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3335"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3371"/>
        <source>Restart</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3464"/>
        <source>Professional mode is only for professionals to use</source>
        <translation>专业模式仅供专业人员使用</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3465"/>
        <source>During the adaptation process, there may be issues such as screen distortion, freezing, stuttering, torn images,
unsynchronized audio and video, and player crashes. Please use with caution.</source>
        <translation>适配过程中可能出现花屏、卡死、卡顿、画面撕裂、音画不同步、
播放器闪退等问题，请谨慎使用。</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3561"/>
        <source>Reading DVD files...</source>
        <translation>正在读取光盘文件...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3829"/>
        <source>No matching online subtitles</source>
        <translation>未找到匹配的在线字幕</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3848"/>
        <source>4K video may be stuck</source>
        <translation>播放4K视频可能会出现卡顿</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3467"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3849"/>
        <source>OK</source>
        <translation>确 定</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3892"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5100"/>
        <source>Order play</source>
        <translation>顺序播放</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3896"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5104"/>
        <source>Shuffle play</source>
        <translation>随机播放</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3900"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5108"/>
        <source>Single play</source>
        <translation>单个播放</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3904"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5112"/>
        <source>Single loop</source>
        <translation>单个循环</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="3908"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5116"/>
        <source>List loop</source>
        <translation>列表循环</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4087"/>
        <source>Buffering...</source>
        <translation>缓冲中...</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4125"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4155"/>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4128"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4158"/>
        <source>Volume: %1%</source>
        <translation>音量：%1%</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4212"/>
        <source>Cannot open file or stream</source>
        <translation>无法打开文件或者流</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4234"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4240"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4247"/>
        <source>Invalid file</source>
        <translation>无效文件</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4243"/>
        <source>Please insert a CD/DVD</source>
        <translation>请插入CD或DVD</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="4252"/>
        <source>No video file found</source>
        <translation>没有找到视频文件</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5089"/>
        <source>Please load the video first</source>
        <translation>请先载入影片</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5248"/>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5259"/>
        <source>Please exit smart dock</source>
        <translation>Please exit smart dock</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5552"/>
        <source>The CD/DVD has been ejected</source>
        <translation>CD/DVD已弹出</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5834"/>
        <source>The action is not supported in this video</source>
        <translation>当前视频不支持该功能</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5846"/>
        <source>Invalid file: %1</source>
        <translation>无效文件：%1</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5875"/>
        <source>Connection failed</source>
        <translation>连接失败</translation>
    </message>
    <message>
        <location filename="../src/common/platform/platform_mainwindow.cpp" line="5883"/>
        <source>Miracast disconnected</source>
        <translation>投屏已断开</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="182"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="289"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="365"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="591"/>
        <source>The file does not exist</source>
        <translation>文件不存在</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="775"/>
        <source>Playlist</source>
        <translation>播放列表</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="801"/>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1051"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1363"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1388"/>
        <location filename="../src/widgets/platform/platform_playlist_widget.cpp" line="1481"/>
        <source>%1 videos</source>
        <translation>%1个视频</translation>
    </message>
</context>
<context>
    <name>dmr::Platform_ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1322"/>
        <source>Play/Pause</source>
        <translation>播放/暂停</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1322"/>
        <source>Previous</source>
        <translation>上一个</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1322"/>
        <source>Next</source>
        <translation>下一个</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1323"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2456"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2958"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1323"/>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2975"/>
        <source>Playlist</source>
        <translation>播放列表</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="1323"/>
        <source>Miracast</source>
        <translation>投屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2452"/>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2543"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../src/widgets/platform/platform_toolbox_proxy.cpp" line="2606"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
</context>
<context>
    <name>dmr::PlayItemWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="180"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="286"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="365"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="596"/>
        <source>The file does not exist</source>
        <translation>文件不存在</translation>
    </message>
</context>
<context>
    <name>dmr::PlaylistWidget</name>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="780"/>
        <source>Playlist</source>
        <translation>播放列表</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="806"/>
        <source>Empty</source>
        <translation>清空</translation>
    </message>
    <message>
        <location filename="../src/widgets/playlist_widget.cpp" line="1054"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1368"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1394"/>
        <location filename="../src/widgets/playlist_widget.cpp" line="1487"/>
        <source>%1 videos</source>
        <translation>%1个视频</translation>
    </message>
</context>
<context>
    <name>dmr::Settings</name>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="165"/>
        <source>Order play</source>
        <translation>顺序播放</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="166"/>
        <source>Shuffle play</source>
        <translation>随机播放</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="167"/>
        <source>Single play</source>
        <translation>单个播放</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="168"/>
        <source>Single loop</source>
        <translation>单个循环</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="169"/>
        <source>List loop</source>
        <translation>列表循环</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="179"/>
        <source>Auto</source>
        <translation>自动</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="180"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="181"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../src/common/dmr_settings.cpp" line="421"/>
        <source>%1/Movie%2(%3).jpg</source>
        <translation>%1/影院%2（%3）.jpg</translation>
    </message>
</context>
<context>
    <name>dmr::ToolboxProxy</name>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1471"/>
        <source>Play/Pause</source>
        <translation>播放/暂停</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1471"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="3272"/>
        <source>Previous</source>
        <translation>上一个</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1471"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="3291"/>
        <source>Next</source>
        <translation>下一个</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1472"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2746"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2748"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="3310"/>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1472"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="3328"/>
        <source>Playlist</source>
        <translation>播放列表</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="1472"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="3366"/>
        <source>Miracast</source>
        <translation>投屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2739"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2741"/>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2849"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2851"/>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2917"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="2919"/>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="3255"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../src/widgets/toolbox_proxy.cpp" line="3347"/>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
</context>
<context>
    <name>dmr::VolumeButton</name>
    <message>
        <location filename="../src/widgets/toolbutton.cpp" line="22"/>
        <source>Volume</source>
        <translation>音量</translation>
    </message>
</context>
</TS>
